summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/umlobject.h')
-rw-r--r--umbrello/umbrello/umlobject.h66
1 files changed, 33 insertions, 33 deletions
diff --git a/umbrello/umbrello/umlobject.h b/umbrello/umbrello/umlobject.h
index d912bafc..56475807 100644
--- a/umbrello/umbrello/umlobject.h
+++ b/umbrello/umbrello/umlobject.h
@@ -13,9 +13,9 @@
#define UMLOBJECT_H
//qt includes
-#include <qobject.h>
-#include <qstring.h>
-#include <qdom.h>
+#include <tqobject.h>
+#include <tqstring.h>
+#include <tqdom.h>
#include "umlnamespace.h"
#include "umlpackagelist.h"
@@ -33,7 +33,7 @@ class UMLObject;
* @author Paul Hensgen <phensgen@techie.com>
* Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
*/
-class UMLObject : public QObject {
+class UMLObject : public TQObject {
Q_OBJECT
public:
@@ -45,7 +45,7 @@ public:
* @param id The ID of the object (optional.) If omitted
* then a new ID will be assigned internally.
*/
- UMLObject(const UMLObject * parent, const QString &name, Uml::IDType id = Uml::id_None);
+ UMLObject(const UMLObject * parent, const TQString &name, Uml::IDType id = Uml::id_None);
/**
* Creates a UMLObject.
@@ -60,7 +60,7 @@ public:
* @param name The name of the object.
* @param id The unique ID of the object.
*/
- explicit UMLObject(const QString &name = "" , Uml::IDType id = Uml::id_None);
+ explicit UMLObject(const TQString &name = "" , Uml::IDType id = Uml::id_None);
/**
* Overloaded '==' operator
@@ -110,14 +110,14 @@ public:
*
* @param d The documentation for the object.
*/
- void setDoc(const QString &d);
+ void setDoc(const TQString &d);
/**
* Returns the documentation for the object.
*
* @return Returns the documentation for the object.
*/
- QString getDoc() const;
+ TQString getDoc() const;
/**
* Returns the visibility of the object.
@@ -139,7 +139,7 @@ public:
*
* @param _name Sets the classes stereotype name.
*/
- void setStereotype(const QString &_name);
+ void setStereotype(const TQString &_name);
/**
* Sets the class' UMLStereotype. Adjusts the reference counts
@@ -158,7 +158,7 @@ public:
*
* @param _name The classes Package name.
*/
- void setPackage(const QString &_name);
+ void setPackage(const TQString &_name);
/**
* Sets the UMLPackage in which this class is located.
@@ -182,7 +182,7 @@ public:
* "«" and "»".
* @return Returns the classes stereotype name.
*/
- QString getStereotype(bool includeAdornments = false) const;
+ TQString getStereotype(bool includeAdornments = false) const;
/**
* Return the package(s) in which this UMLObject is contained
@@ -196,7 +196,7 @@ public:
* Default: false.
* @return The UMLObject's enclosing package(s) as a text.
*/
- QString getPackage(const QString& separator = QString::null,
+ TQString getPackage(const TQString& separator = TQString::null,
bool includeRoot = false);
/**
@@ -224,12 +224,12 @@ public:
/**
* Returns a copy of m_Name
*/
- QString getName() const;
+ TQString getName() const;
/**
* Set the UMLObject's name
*/
- virtual void setName(const QString &strName);
+ virtual void setName(const TQString &strName);
/**
* Returns the fully qualified name, i.e. all package prefixes and then m_Name.
@@ -242,7 +242,7 @@ public:
* See UMLDoc::getRootFolder(). Default: false.
* @return The fully qualified name of this UMLObject.
*/
- virtual QString getFullyQualifiedName(const QString& separator = QString::null,
+ virtual TQString getFullyQualifiedName(const TQString& separator = TQString::null,
bool includeRoot = false) const;
/**
@@ -287,10 +287,10 @@ public:
/**
* This method saves the XMI attributes of each specific model class.
* It needs to be implemented by each child class.
* For creating the QDomElement and saving the common XMI parts,
* it can use the save() method.
*/
- virtual void saveToXMI( QDomDocument & qDoc, QDomElement & qElement ) = 0;
+ virtual void saveToXMI( TQDomDocument & qDoc, TQDomElement & qElement ) = 0;
/**
* This method loads the generic parts of the XMI common to most model
@@ -298,17 +298,17 @@ public:
* Instead, it invokes the load() method which implements the loading
* of the specifics of each child class.
*
* @param element The QDomElement from which to load.
*/
- virtual bool loadFromXMI( QDomElement & element );
+ virtual bool loadFromXMI( TQDomElement & element );
/**
* Analyzes the given QDomElement for a reference to a stereotype.
*
* @param element QDomElement to analyze.
* @return True if a stereotype reference was found, else false.
*/
- bool loadStereotype(QDomElement & element);
+ bool loadStereotype(TQDomElement & element);
/**
* Returns true if this UMLObject has classifier scope,
@@ -339,34 +339,34 @@ public:
/**
* Return secondary ID. Required by resolveRef().
*/
- QString getSecondaryId() const;
+ TQString getSecondaryId() const;
/**
* Set the secondary ID.
* Currently only required by petalTree2Uml(); all other setting of the
* m_SecondaryID is internal to the UMLObject class hierarchy.
*/
- void setSecondaryId(const QString& id);
+ void setSecondaryId(const TQString& id);
/**
* Return secondary ID fallback.
* Required by resolveRef() for imported model files.
*/
- QString getSecondaryFallback() const;
+ TQString getSecondaryFallback() const;
/**
* Set the secondary ID fallback.
* Currently only used by petalTree2Uml().
*/
- void setSecondaryFallback(const QString& id);
+ void setSecondaryFallback(const TQString& id);
/**
* Auxiliary to saveToXMI.
* Create a QDomElement with the given tag, and save the XMI attributes
* that are common to all child classes to the newly created element.
* This method does not need to be overridden by child classes.
*/
- QDomElement save( const QString &tag, QDomDocument & qDoc );
+ TQDomElement save( const TQString &tag, TQDomDocument & qDoc );
public slots:
/**
@@ -402,7 +402,7 @@ protected:
* It is responsible for loading the specific XMI structure
* of the child class.
*/
- virtual bool load( QDomElement& element );
+ virtual bool load( TQDomElement& element );
/**
* The object's id.
@@ -412,7 +412,7 @@ protected:
/**
* The object's documentation.
*/
- QString m_Doc;
+ TQString m_Doc;
/**
* The package the object belongs to if applicable.
@@ -427,7 +427,7 @@ protected:
/**
* The objects name.
*/
- QString m_Name;
+ TQString m_Name;
/**
* The objects type.
@@ -473,7 +473,7 @@ protected:
* loading. The secondary ID is resolved to the m_pSecondary
* in the course of resolveRef() at the end of loading.
*/
- QString m_SecondaryId;
+ TQString m_SecondaryId;
/**
* Last-chance backup for when m_SecondaryId is not found.
@@ -483,7 +483,7 @@ protected:
* In case the quidu is not found, the human readable name is
* used which we store in m_SecondaryFallback.
*/
- QString m_SecondaryFallback;
+ TQString m_SecondaryFallback;
};
/**
@@ -287,10 +287,10 @@ public:
* This method saves the XMI attributes of each specific model class.
* It needs to be implemented by each child class.
- * For creating the QDomElement and saving the common XMI parts,
+ * For creating the TQDomElement and saving the common XMI parts,
* it can use the save() method.
*/
@@ -298,17 +298,17 @@ public:
* of the specifics of each child class.
*
- * @param element The QDomElement from which to load.
+ * @param element The TQDomElement from which to load.
*/
@@ -298,17 +298,17 @@ public:
/**
- * Analyzes the given QDomElement for a reference to a stereotype.
+ * Analyzes the given TQDomElement for a reference to a stereotype.
*
@@ -298,17 +298,17 @@ public:
*
- * @param element QDomElement to analyze.
+ * @param element TQDomElement to analyze.
* @return True if a stereotype reference was found, else false.
*/
@@ -339,34 +339,34 @@ public:
/**
* Auxiliary to saveToXMI.
- * Create a QDomElement with the given tag, and save the XMI attributes
+ * Create a TQDomElement with the given tag, and save the XMI attributes
* that are common to all child classes to the newly created element.
* This method does not need to be overridden by child classes.